@@ -37,6 +37,7 @@ class API(object):
     CUSTOM_VERIFIER_CHALLENGE = 'CUSTOM_CHALLENGE'
 
     username = attr.ib()
+    code_type = attr.ib(default=None)
     user_pool_region = attr.ib()
 
     id_token = attr.ib(default=None)
@@ -223,22 +224,25 @@ class API(object):
             for k, v in attribute_dict.items():
                 setattr(self, k, v)
 
-    async def authenticate(self, password):
+    async def authenticate(self, password, code_type):
         """
         Authenticate the user using the SRP protocol
         :param password: The user's passsword
         :return:
         """
         self.aws = AWSKWIKSET(username=self.username, password=password,
+                     code_type=code_type,
                      pool_id=self.user_pool_id,
                      client_id=self.client_id, client=self.get_client(),
                      client_secret=self.client_secret)
 
+        self.code_type = code_type
+
         pre_verification = await self.aws.authenticate_user()
         return pre_verification
 
     async def verify_user(self, pre_verification, code):
-        challenge_responses = {'ANSWER': 'answerType:verifyCode,medium:phone,codeType:login,code:{}'.format(code),"USERNAME": self.username}
+        challenge_responses = {'ANSWER': 'answerType:verifyCode,medium:{},codeType:login,code:{}'.format(self.code_type, code),"USERNAME": self.username}
 
         async with self.get_client() as client:
             tokens = await client.respond_to_auth_challenge(
@@ -247,6 +251,7 @@ class API(object):
                 Session=pre_verification['Session'],
                 ChallengeResponses=challenge_responses)
 
+
             await self.verify_token(tokens['AuthenticationResult']['IdToken'],
                                     'id_token', 'id')
             self.refresh_token = tokens['AuthenticationResult']['RefreshToken']
