@@ -2,7 +2,7 @@
 from typing import Awaitable, Callable
 import json
 
-from .const import COMMAND_URL, GET_HOME_DEVICES_URL, GET_DEVICE_URL
+from .const import LOCK_COMMAND_URL, ACCESSORY_COMMAND_URL, GET_HOME_DEVICES_URL, GET_DEVICE_URL
 
 
 class Device():  # pylint: disable=too-few-public-methods
@@ -39,7 +39,7 @@ class Device():  # pylint: disable=too-few-public-methods
         for items in device_info['data']:
             return items
 
-    async def _set_action(self, dev, user, action: str):
+    async def _lock_action(self, dev, user, action: str):
         data = json.dumps({
           "action": action,
           "source": "{\"name\":\"%s\",\"device\":\"%s\"}"
@@ -47,13 +47,34 @@ class Device():  # pylint: disable=too-few-public-methods
 
         r = await self._request(
             'patch',
-            COMMAND_URL % (dev['serialnumber']),
+            LOCK_COMMAND_URL % (dev['serialnumber']),
+            data=data,
+        )
+        return r['data']
+
+    async def _set_action(self, dev, action, status):
+        data = json.dumps({
+          action: status,
+        })
+
+        r = await self._request(
+            'patch',
+            ACCESSORY_COMMAND_URL % (dev['serialnumber'], action),
             data=data,
         )
         return r['data']
 
     async def lock_device(self, dev, user):
-        return await self._set_action(dev, user, 'lock')
+        return await self._lock_action(dev, user, 'lock')
 
     async def unlock_device(self, dev, user):
-        return await self._set_action(dev, user, 'unlock')
\ No newline at end of file
+        return await self._lock_action(dev, user, 'unlock')
+
+    async def set_ledstatus(self, dev, status):
+        return await self._set_action(dev, 'ledstatus', status)
+
+    async def set_audiostatus(self, dev, status):
+        return await self._set_action(dev, 'audiostatus', status)
+
+    async def set_securescreenstatus(self, dev, status):
+        return await self._set_action(dev, 'securescreenstatus', status)
\ No newline at end of file
